require "active_audit/version"
require "active_audit/configuration"

module ActiveAudit

  class << self
    attr_accessor :configuration
  end

  def self.configuration
    @configuration ||= Configuration.new
  end

  def self.configuration=(config)
    @configuration = config
  end

  def self.configure
    yield(configuration)
  end

end

require "active_audit/auditable"
require "generators/active_audit/install_generator"

if defined?(Rails)
  require 'rails'

  module ActiveAudit
    class Railtie < ::Rails::Railtie

      initializer 'active_audit' do |app|
        ActiveAudit::Railtie.instance_eval do
          [app.config.i18n.available_locales].flatten.each do |locale|
            (I18n.load_path << path(locale)) if File.file?(path(locale))
          end
        end
      end

      protected

      def self.path(locale)
        File.expand_path("../../config/locales/#{locale}.yml", __FILE__)
      end

    end
  end
end