class Audit < ActiveRecord::Base

  SOURCES = { app: 0, api: 1 }

  belongs_to :auditable, polymorphic: true
  belongs_to :user

  enum source: SOURCES

  serialize :revisions

  validates :action,         presence: true
  validates :auditable_id,   numericality: { integer: true }
  validates :auditable_type, presence: true
  validates :source,         inclusion: SOURCES.dup.keys.map { |key| key.to_s }
  validates :user_id,        numericality: { integer: true },
                             allow_blank: true,
                             allow_nil: true

  def self.record!(object, action, user: ActiveAudit.configuration.auditor, source: :app, comment: nil, remote_ip: nil, remote_uuid: nil)
    create!({
      auditable:   object,
      user:        user,
      source:      source,
      action:      action,
      revisions:   object.changes,
      comment:     comment,
      remote_ip:   remote_ip,
      remote_uuid: remote_uuid
    })
  end

end